@@ -1,6 +1,6 @@
 /* A Scheme reader compiler for Guile.
 
-   Copyright (C) 2005, 2006, 2007  Ludovic Courts  <ludovic.courtes@laas.fr>
+   Copyright (C) 2005, 2006, 2007, 2008  Ludovic Courts <ludo@gnu.org>
 
    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -16,6 +16,10 @@
    along with this program; if not, write to the Free Software
    Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301 USA  */
 
+#ifdef HAVE_CONFIG_H
+# include <config.h>
+#endif
+
 #include <stdlib.h>
 #include <stdio.h>
 #include <ctype.h>
@@ -29,8 +33,6 @@
 #include "token-readers.h"
 #include "reader-lib.h"
 
-#include "config.h" /* this defines `inline' among other things */
-
 #ifdef SCM_READER_USE_LIGHTNING
 # include <lightning.h>
 
